@@ -4,9 +4,11 @@ use warnings;
 package Dist::Zilla::Plugin::PortabilityTests;
 # ABSTRACT: (DEPRECATED) Release tests for portability
 
-our $VERSION = '2.001000';
+our $VERSION = '2.001001';
 
 use Moose;
+use namespace::autoclean;
+
 extends 'Dist::Zilla::Plugin::Test::Portability';
 
 before register_component => sub {
@@ -29,7 +31,7 @@ Dist::Zilla::Plugin::PortabilityTests - (DEPRECATED) Release tests for portabili
 
 =head1 VERSION
 
-version 2.001000
+version 2.001001
 
 =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
@@ -50,6 +52,12 @@ later time (but not before February 2017).
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-Portability>
 (or L<bug-Dist-Zilla-Plugin-Test-Portability@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-Portability@rt.cpan.org>).
 
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHORS
 
 =over 4
@@ -68,9 +76,9 @@ Mike Doherty <doherty@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2010 by Karen Etheridge.
+This software is copyright (c) 2010 by Mike Doherty.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
